@@ -42,8 +42,8 @@ def create_app(console):
 
   return app
 
-def start_server(password, username, upstreamh='0.0.0.0', upstreamp=55553, host="0.0.0.0", port=65432, *args, **kwargs):
-  client = MsfRpcClient(password, username=username, server=upstreamh, port=upstreamp)
+def start_server(password, username, upstreams=False, upstreamh='0.0.0.0', upstreamp=55553, host="0.0.0.0", port=65432, *args, **kwargs):
+  client = MsfRpcClient(password, username=username, ssl=upstreams, server=upstreamh, port=upstreamp)
   c_id = client.call(MsfRpcMethod.ConsoleCreate)['id']
   console = client.consoles.console(c_id)
   app = create_app(console, **kwargs)
